@@ -36,10 +36,53 @@ output_mapping = {
     'none': None
     }
 
+
 def extract_data(invoicefile, templates=None, input_module=pdftotext):
+    """Extracts structured data from PDF/image invoices.
+
+    This function uses the text extracted from a PDF file or image and
+    pre-defined regex templates to find structured data.
+
+    Reads template if no template assigned
+    Required fields are matches from templates
+
+    Parameters
+    ----------
+    invoicefile : str
+        path of electronic invoice file in PDF,JPEG,PNG (example: "/home/duskybomb/pdf/invoice.pdf")
+    templates : list of instances of class `InvoiceTemplate`, optional
+        Templates are loaded using `read_template` function in `loader.py`
+    input_module : {'pdftotext', 'pdfminer', 'tesseract'}, optional
+        library to be used to extract text from given `invoicefile`,
+
+    Returns
+    -------
+    dict or False
+        extracted and matched fields or False if no template matches
+
+    Notes
+    -----
+    Import required `input_module` when using invoice2data as a library
+
+    See Also
+    --------
+    read_template : Function where templates are loaded
+    InvoiceTemplate : Class representing single template files that live as .yml files on the disk
+
+    Examples
+    --------
+    When using `invoice2data` as an library
+
+    >>> from invoice2data.input import pdftotext
+    >>> extract_data("invoice2data/test/pdfs/oyo.pdf", None, pdftotext)
+    {'issuer': 'OYO', 'amount': 1939.0, 'date': datetime.datetime(2017, 12, 31, 0, 0), 'invoice_number': 'IBZY2087',
+     'currency': 'INR', 'desc': 'Invoice IBZY2087 from OYO'}
+
+    """
     if templates is None:
         templates = read_templates()
 
+    # print(templates[0])
     extracted_str = input_module.to_text(invoicefile).decode('utf-8')
 
     logger.debug('START pdftotext result ===========================')
@@ -57,14 +100,13 @@ def extract_data(invoicefile, templates=None, input_module=pdftotext):
     return False
 
 def create_parser():
-    '''Returns argument parser '''
+    """Returns argument parser """
 
     parser = argparse.ArgumentParser(description='Extract structured data from PDF files and save to CSV or JSON.')
 
     parser.add_argument('--input-reader', choices=input_mapping.keys(),
                         default='pdftotext', help='Choose text extraction function. Default: pdftotext')
 
-
     parser.add_argument('--output-format', choices=output_mapping.keys(),
                         default='none', help='Choose output format. Default: none')
 
@@ -88,8 +130,9 @@ def create_parser():
 
     return parser
 
+
 def main(args=None):
-    '''Take folder or single file and analyze each.'''
+    """Take folder or single file and analyze each."""
     if args is None:
         parser = create_parser()
         args = parser.parse_args()
@@ -127,6 +170,7 @@ def main(args=None):
     if output_module is not None:
         output_module.write_to_file(output, args.output_name)
 
+
 if __name__ == '__main__':
     main()
 
